@@ -1,7 +1,6 @@
 /*
- * $Id: nemesis-arp.h,v 1.8 2000/03/04 10:45:05 obecian Exp $
- *
- * THE NEMESIS PROJECT (c) obecian 1999, 2000
+ * THE NEMESIS PROJECT
+ * Copyright (C) 1999, 2000 Mark Grimes <obecian@packetninja.net>
  *
  * nemesis-arp.h (ARP Packet Injector)
  *
@@ -9,8 +8,8 @@
 
 
 #define TITLE "ARP Packet Injection -=- The NEMESIS Project -=- "
-#define VERSION "1.0"
-#define CODERS "(c) 1999, 2000 obecian <obecian@celerity.bartoli.org>"
+#define VERSION "1.2"
+#define CODERS "Copyright (C) 1999, 2000 Mark Grimes <obecian@packetninja.net>"
 
 #include <stdio.h>
 #include <strings.h>
@@ -25,6 +24,7 @@
 #define SNAPLEN 128
 #define TIMEOUT 1024
 #define OPTIMIZE 0
+#define PADDING 15
 
 u_int			enet_tmp[6];
 u_long          source,		/* source address */
@@ -51,6 +51,7 @@ int             verbose;	/* verbosity */
 
 int             buildarp();
 
+void						hexdump(char *, int);
 void            usage(char *);
 void            defaults();	/* defaults for packet fields */
 
