@@ -1,7 +1,6 @@
 /*
- * $Id: nemesis-proto_ospf.c,v 1.5 2000/02/14 03:45:49 obecian Exp $
- *
  * THE NEMESIS PROJECT (c) obecian 1999, 2000
+ * Copyright (C) 1999, 2000 Mark Grimes <obecian@packetninja.net>
  *
  * nemesis-proto_ospf.c (OSPF Packet Generator)
  *
@@ -74,10 +73,15 @@ build_hello() /* OSPF Hello */
 		exit(1);
 	}
 
-	if (payload != NULL)
-		payload_s = strlen(payload);
-	if (*options != NULL)
-		option_s = strlen(options);
+  if (payload == NULL)
+    payload_s = 0;
+  else
+    payload_s = strlen(payload);
+
+  if (*options == NULL)
+    option_s = 0;
+  else
+    option_s = strlen(options);
 	
 	pkt = malloc(IP_MAXPACKET);
 	sockfd = libnet_open_raw_sock(IPPROTO_RAW);
